@@ -1,9 +1,9 @@
 /*
- *  $Id: editbox.c,v 1.74 2019/08/05 09:15:36 tom Exp $
+ *  $Id: editbox.c,v 1.85 2022/04/06 08:01:23 tom Exp $
  *
  *  editbox.c -- implements the edit box
  *
- *  Copyright 2007-2018,2019 Thomas E. Dickey
+ *  Copyright 2007-2020,2022 Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -21,11 +21,9 @@
  *	Boston, MA 02110, USA.
  */
 
-#include <dialog.h>
+#include <dlg_internals.h>
 #include <dlg_keys.h>
 
-#include <sys/stat.h>
-
 #define sTEXT -1
 
 static void
@@ -275,7 +273,8 @@ col_to_chr_offset(const char *text, int col)
     return result;
 }
 
-#define SCROLL_TO(target) show_all = scroll_to(pagesize, listsize, &base_row, &thisrow, target)
+#define Scroll_To(target) scroll_to(pagesize, listsize, &base_row, &thisrow, target)
+#define SCROLL_TO(target) show_all = Scroll_To(target)
 
 #define PREV_ROW (*list)[thisrow - 1]
 #define THIS_ROW (*list)[thisrow]
@@ -286,7 +285,7 @@ col_to_chr_offset(const char *text, int col)
 static int
 widest_line(char **list)
 {
-    int result = MAX_LEN;
+    int result = dlg_max_input(-1);
 
     if (list != 0) {
 	char *value;
@@ -358,8 +357,8 @@ dlg_editbox(const char *title,
     int result = DLG_EXIT_UNKNOWN;
     int state;
     size_t max_len = (size_t) dlg_max_input(widest_line(*list));
-    char *input, *buffer;
-    bool show_all, show_one, was_mouse;
+    char *buffer;
+    bool show_all, show_one;
     bool first_trace = TRUE;
     WINDOW *dialog;
     WINDOW *editing;
@@ -439,7 +438,8 @@ dlg_editbox(const char *title,
     pagesize = getmaxy(editing);
 
     while (result == DLG_EXIT_UNKNOWN) {
-	int edit = 0;
+	bool was_mouse;
+	char *input;
 
 	if (show_all) {
 	    display_all(editing, *list, thisrow, base_row, listsize, chr_offset);
@@ -557,6 +557,8 @@ dlg_editbox(const char *title,
 	}
 
 	if (state == sTEXT) {	/* editing box selected */
+	    int edit = 0;
+
 	    /*
 	     * Intercept scrolling keys that dlg_edit_string() does not
 	     * understand.
@@ -613,7 +615,7 @@ dlg_editbox(const char *title,
 			    }
 			    --listsize;
 			    --thisrow;
-			    SCROLL_TO(thisrow);
+			    (void) Scroll_To(thisrow);
 
 			    show_all = TRUE;
 			}
@@ -638,6 +640,8 @@ dlg_editbox(const char *title,
 		}
 	    }
 	    strncpy(buffer, input, max_len - 1)[max_len - 1] = '\0';
+	    if (chr_offset > (int) (max_len - 1))
+		chr_offset = (int) (max_len - 1);
 	    edit = dlg_edit_string(buffer, &chr_offset, key, fkey, FALSE);
 
 	    if (edit) {
@@ -692,24 +696,26 @@ dlg_editbox(const char *title,
 		    chr_offset = 0;
 		    col_offset = 0;
 		    THIS_ROW = tmp;
-		    SCROLL_TO(thisrow);
+		    (void) Scroll_To(thisrow);
 		    show_all = TRUE;
 		} else {
-		    result = dlg_ok_buttoncode(state);
+		    result = dlg_enter_buttoncode(state);
 		}
 		break;
+	    case DLGK_LEAVE:
+		if (state >= 0)
+		    result = dlg_ok_buttoncode(state);
+		break;
 #ifdef KEY_RESIZE
 	    case KEY_RESIZE:
 		dlg_will_resize(dialog);
 		/* reset data */
 		height = old_height;
 		width = old_width;
-		dlg_clear();
-		dlg_unregister_window(editing);
-		dlg_del_window(editing);
-		dlg_del_window(dialog);
-		dlg_mouse_free_regions();
 		/* repaint */
+		dlg_del_window(editing);
+		dlg_unregister_window(editing);
+		_dlg_resize_cleanup(dialog);
 		goto retry;
 #endif
 	    case DLGK_TOGGLE:
