@@ -1,9 +1,9 @@
 /*
- *  $Id: guage.c,v 1.78 2019/07/24 23:40:26 tom Exp $
+ *  $Id: guage.c,v 1.85 2022/04/03 22:38:16 tom Exp $
  *
  *  guage.c -- implements the gauge dialog
  *
- *  Copyright 2000-2018,2019	Thomas E. Dickey
+ *  Copyright 2000-2021,2022	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -24,9 +24,7 @@
  *	Marc Ewing, Red Hat Software
  */
 
-#include <dialog.h>
-
-#include <errno.h>
+#include <dlg_internals.h>
 
 #define MY_LEN (MAX_LEN)/2
 
@@ -182,15 +180,18 @@ static bool
 handle_input(DIALOG_CALLBACK * cb)
 {
     MY_OBJ *obj = (MY_OBJ *) cb;
+    FILE *my_input = ((obj != NULL && obj->obj.input != NULL)
+		      ? obj->obj.input
+		      : dialog_state.pipe_input);
     bool result;
     bool cleanup = FALSE;
     int status;
     char buf[MY_LEN + 1];
 
-    if (dialog_state.pipe_input == 0) {
+    if (my_input == NULL) {
 	status = -1;
 	cleanup = TRUE;
-    } else if ((status = read_data(buf, dialog_state.pipe_input)) > 0) {
+    } else if ((status = read_data(buf, my_input)) > 0) {
 
 	if (isMarker(buf)) {
 	    /*
@@ -198,7 +199,7 @@ handle_input(DIALOG_CALLBACK * cb)
 	     * worse-written clones of 'dialog' assumes the number is missing.
 	     * (Gresham's Law applied to software).
 	     */
-	    if ((status = read_data(buf, dialog_state.pipe_input)) > 0) {
+	    if ((status = read_data(buf, my_input)) > 0) {
 
 		obj->prompt_buf[0] = '\0';
 		if (decode_percent(buf))
@@ -207,7 +208,7 @@ handle_input(DIALOG_CALLBACK * cb)
 		    strcpy(obj->prompt_buf, buf);
 
 		/* Rest is message text */
-		while ((status = read_data(buf, dialog_state.pipe_input)) > 0
+		while ((status = read_data(buf, my_input)) > 0
 		       && !isMarker(buf)) {
 		    if (strlen(obj->prompt_buf) + strlen(buf) <
 			sizeof(obj->prompt_buf) - 1) {
@@ -223,8 +224,8 @@ handle_input(DIALOG_CALLBACK * cb)
 	    obj->percent = atoi(buf);
 	}
     } else {
-	if (feof(dialog_state.pipe_input) ||
-	    (ferror(dialog_state.pipe_input) && errno != EINTR)) {
+	if (feof(my_input) ||
+	    (ferror(my_input) && errno != EINTR)) {
 	    cleanup = TRUE;
 	}
     }
@@ -302,7 +303,7 @@ dlg_reallocate_gauge(void *objptr,
 		     int percent)
 {
     char *prompt = dlg_strclone(cprompt);
-    MY_OBJ *obj = objptr;
+    MY_OBJ *obj;
     bool save_finish_string = dialog_state.finish_string;
 
     dialog_state.finish_string = TRUE;
@@ -427,7 +428,6 @@ dialog_gauge(const char *title,
 	    MY_OBJ *oldobj = obj;
 
 	    dlg_will_resize(obj->obj.win);
-	    dlg_mouse_free_regions();
 
 	    obj = dlg_allocate_gauge(title,
 				     cprompt,
@@ -441,9 +441,8 @@ dialog_gauge(const char *title,
 	    oldobj->obj.keep_win = FALSE;
 
 	    /* remove the old version of the gauge */
-	    dlg_clear();
+	    _dlg_resize_cleanup(oldobj->obj.win);
 	    dlg_remove_callback(&(oldobj->obj));
-	    refresh();
 
 	    dlg_add_callback_ref((DIALOG_CALLBACK **) & obj, my_cleanup);
 	    dlg_update_gauge(obj, obj->percent);
