@@ -1,9 +1,9 @@
 /*
- *  $Id: inputstr.c,v 1.92 2021/12/13 22:04:24 tom Exp $
+ *  $Id: inputstr.c,v 1.95 2022/04/06 08:03:09 tom Exp $
  *
  *  inputstr.c -- functions for input/display of a string
  *
- *  Copyright 2000-2019,2021	Thomas E. Dickey
+ *  Copyright 2000-2021,2022	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -21,25 +21,8 @@
  *	Boston, MA 02110, USA.
  */
 
-#include <dialog.h>
-#include <dlg_keys.h>
 #include <dlg_internals.h>
-
-#include <errno.h>
-
-#ifdef HAVE_SETLOCALE
-#include <locale.h>
-#endif
-
-#if defined(HAVE_SEARCH_H) && defined(HAVE_TSEARCH)
-#include <search.h>
-#else
-#undef HAVE_TSEARCH
-#endif
-
-#ifdef NEED_WCHAR_H
-#include <wchar.h>
-#endif
+#include <dlg_keys.h>
 
 #if defined(USE_WIDE_CURSES)
 #define USE_CACHING 1
@@ -527,7 +510,6 @@ dlg_edit_string(char *string, int *chr_offset, int key, int fkey, bool force)
     int limit = dlg_count_wchars(string);
     const int *indx = dlg_index_wchars(string);
     int offset = dlg_find_index(indx, limit, *chr_offset);
-    int max_len = dlg_max_input(MAX_LEN);
     bool edit = TRUE;
 
     /* transform editing characters into equivalent function-keys */
@@ -630,7 +612,7 @@ dlg_edit_string(char *string, int *chr_offset, int key, int fkey, bool force)
 	if (key == ESC || key == ERR) {
 	    edit = 0;
 	} else {
-	    if (len < max_len) {
+	    if (len < dlg_max_input(-1)) {
 		for (i = ++len; i > *chr_offset; i--)
 		    string[i] = string[i - 1];
 		string[*chr_offset] = (char) key;
