@@ -1,9 +1,9 @@
 /*
- * $Id: mousewget.c,v 1.23 2016/02/03 10:22:40 tom Exp $
+ *  $Id: mousewget.c,v 1.26 2022/04/03 22:39:39 tom Exp $
  *
- * mousewget.c -- mouse/wgetch support for dialog
+ *  mousewget.c -- mouse/wgetch support for dialog
  *
- * Copyright 2000-2012,2016   Thomas E. Dickey
+ *  Copyright 2000-2019,2022	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -21,7 +21,7 @@
  *	Boston, MA 02110, USA.
  */
 
-#include <dialog.h>
+#include <dlg_internals.h>
 #include <dlg_keys.h>
 
 static int
@@ -39,13 +39,14 @@ mouse_wgetch(WINDOW *win, int *fkey, bool ignore_errs)
 	mouse_err = FALSE;
 	if (key == KEY_MOUSE) {
 	    MEVENT event;
-	    mseRegion *p;
 
 	    if (getmouse(&event) != ERR) {
-		dlg_trace_msg("# mouse-click abs %d,%d (rel %d,%d)\n",
-			      event.y, event.x,
-			      event.y - getbegy(win),
-			      event.x - getbegx(win));
+		mseRegion *p;
+
+		DLG_TRACE(("# mouse-click abs %d,%d (rel %d,%d)\n",
+			   event.y, event.x,
+			   event.y - getbegy(win),
+			   event.x - getbegx(win)));
 		if ((p = dlg_mouse_region(event.y, event.x)) != 0) {
 		    key = DLGK_MOUSE(p->code);
 		} else if ((p = dlg_mouse_bigregion(event.y, event.x)) != 0) {
