@@ -1,9 +1,9 @@
 /*
- *  $Id: pause.c,v 1.48 2020/11/23 00:38:19 tom Exp $
+ *  $Id: pause.c,v 1.49 2022/04/03 22:38:16 tom Exp $
  *
  *  pause.c -- implements the pause dialog
  *
- *  Copyright 2004-2019,2020	Thomas E. Dickey
+ *  Copyright 2004-2020,2022	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -24,7 +24,7 @@
  *	Yura Kalinichenko
  */
 
-#include <dialog.h>
+#include <dlg_internals.h>
 #include <dlg_keys.h>
 
 #define MY_TIMEOUT 50
